@@ -356,8 +356,8 @@ vnc_auth_unsupported_cb (VncDisplay *vnc, guint auth_type, VinagreVncTab *vnc_ta
   name = vinagre_connection_get_best_name (vinagre_tab_get_conn (tab));
   emphasis = g_strdup_printf ("<i>%s</i>", name);
 
-  /* Translators: %s is a host name or IP address; %u is a code error (number). Also, the right sentence would be ... method for host... */
-  g_string_printf (message, _("Authentication method to host %s is unsupported. (%u)"),
+  /* Translators: %s is a host name or IP address; %u is a code error (number). */
+  g_string_printf (message, _("Authentication method for host %s is unsupported. (%u)"),
 		   emphasis,
 		   auth_type);
 
@@ -577,7 +577,7 @@ vnc_pointer_ungrab_cb (VncDisplay *vnc, VinagreVncTab *vnc_tab)
 static void
 vnc_bell_cb (VncDisplay *vnc, VinagreVncTab *vnc_tab)
 {
-  gdk_window_beep (GTK_WIDGET (vnc_tab)->window);
+  gdk_window_beep (gtk_widget_get_window (GTK_WIDGET (vnc_tab)));
 }
 
 static void
@@ -681,7 +681,7 @@ create_initialized_actions (VinagreVncTab *tab)
   a->paths[1] = g_strdup ("/ToolBar");
   a->paths[2] = NULL;
   a->action = gtk_action_new ("VNCMachineSendCtrlAltDel",
-			      _("Send Ctrl-Alt-Del"),
+			      _("_Send Ctrl-Alt-Del"),
 			      _("Sends Ctrl+Alt+Del to the remote machine"),
 			      "preferences-desktop-keyboard-shortcuts");
   gtk_action_set_is_important (a->action, TRUE);
